@@ -1,4 +1,5 @@
 """Run third-party tool (e.g. :code:`mypy`) against notebook or directory."""
+import json
 import os
 import re
 import subprocess
@@ -8,6 +9,7 @@ from importlib import import_module
 from pathlib import Path
 from textwrap import dedent
 from typing import (
+    Any,
     Dict,
     Iterator,
     Mapping,
@@ -19,12 +21,12 @@ from typing import (
     Tuple,
 )
 
-import toml
+import tomli
 from pkg_resources import parse_version
 
 from nbqa import replace_source, save_source
 from nbqa.cmdline import CLIArgs
-from nbqa.config.config import Configs, get_default_config, validate
+from nbqa.config.config import Configs, get_default_config
 from nbqa.find_root import find_project_root
 from nbqa.notebook_info import NotebookInfo
 from nbqa.optional import metadata
@@ -277,10 +279,9 @@ def _get_command_not_found_msg(command: str) -> str:
 
         Please make sure you have it installed in the same Python environment as nbqa. See
         e.g. {VIRTUAL_ENVIRONMENTS_URL} for how to set up
-        a virtual environment in Python.
+        a virtual environment in Python, and run:
 
-        Since nbqa is installed at {{nbqa_loc}} and uses the Python executable found at
-        {{python}}, you could fix this issue by running `{{python}} -m pip install {command}`.
+            `python -m pip install {command}`.
         """
     )
     python_executable = sys.executable
@@ -309,9 +310,10 @@ def _get_configs(cli_args: CLIArgs, project_root: Path) -> Configs:
     config = get_default_config()
 
     # If a section is in pyproject.toml, use that.
-    if (project_root / "pyproject.toml").is_file():
+    pyproject_path = project_root / "pyproject.toml"
+    if pyproject_path.is_file():
 
-        config_file = toml.load(str(project_root / "pyproject.toml"))
+        config_file = tomli.loads(pyproject_path.read_text("utf-8"))
         if "tool" in config_file and "nbqa" in config_file["tool"]:
             file_config = config_file["tool"]["nbqa"]
             for section in config:
@@ -322,8 +324,12 @@ def _get_configs(cli_args: CLIArgs, project_root: Path) -> Configs:
     # If a section was passed via CLI, use that.
     for section in config:
         if getattr(cli_args, section) is not None:
-            # TypedDict key must be a string literal
-            config[section] = getattr(cli_args, section)  # type: ignore
+            if section == "addopts":
+                # addopts are added to / overridden rather than replaced outright
+                config["addopts"] = (*config["addopts"], *getattr(cli_args, section))
+            else:
+                # TypedDict key must be a string literal
+                config[section] = getattr(cli_args, section)  # type: ignore
 
     # add default options
     if cli_args.command == "isort":
@@ -410,6 +416,18 @@ def _print_failed_notebook_errors(failed_notebooks: Mapping[str, str]) -> None:
     sys.stderr.write("\n")
 
 
+def _is_non_python_notebook(notebook: MutableMapping[str, Any]) -> bool:
+    """
+    If notebook is marked as non-Python, don't format it.
+
+    All notebook metadata fields are optional, see
+    https://nbformat.readthedocs.io/en/latest/format_description.html. So
+    if a notebook has empty metadata, we will try to parse it anyway.
+    """
+    language = notebook.get("metadata", {}).get("language_info", {}).get("name", None)
+    return language is not None and language != "python"
+
+
 def _main(  # pylint: disable=R0912,R0914,R0911
     cli_args: CLIArgs, configs: Configs
 ) -> int:
@@ -437,6 +455,7 @@ def _main(  # pylint: disable=R0912,R0914,R0911
         return 1
 
     failed_notebooks = {}
+    non_python_notebooks = set()
     try:  # pylint disable=R0912
 
         if not nb_to_py_mapping:
@@ -449,9 +468,15 @@ def _main(  # pylint: disable=R0912,R0914,R0911
         nb_info_mapping: MutableMapping[str, NotebookInfo] = {}
 
         for notebook, (file_descriptor, _) in nb_to_py_mapping.items():
+            with open(str(notebook), encoding="utf-8") as handle:
+                content = handle.read()
             try:
+                notebook_json = json.loads(content)
+                if _is_non_python_notebook(notebook_json):
+                    non_python_notebooks.add(notebook)
+                    continue
                 nb_info_mapping[notebook] = save_source.main(
-                    notebook,
+                    notebook_json,
                     file_descriptor,
                     configs["process_cells"],
                     cli_args.command,
@@ -478,7 +503,7 @@ def _main(  # pylint: disable=R0912,R0914,R0911
 
         actually_mutated = False
         for notebook, (_, temp_python_file) in nb_to_py_mapping.items():
-            if notebook in failed_notebooks:
+            if notebook in failed_notebooks or notebook in non_python_notebooks:
                 continue
             output = _replace_temp_python_file_references_in_out_err(
                 temp_python_file, notebook, output.out, output.err
@@ -492,23 +517,6 @@ def _main(  # pylint: disable=R0912,R0914,R0911
             )
 
             if mutated:
-                if not configs["mutate"] and not configs["diff"]:
-                    # pylint: disable=C0301
-                    msg = dedent(
-                        f"""\
-                        {BOLD}Mutation detected, will not reformat! Please use the `--nbqa-mutate` flag, e.g.:{RESET}
-
-                            nbqa {cli_args.command} notebook.ipynb --nbqa-mutate
-
-                        or, to only preview changes, use the `--nbqa-diff` flag, e.g.:
-
-                            nbqa {cli_args.command} notebook.ipynb --nbqa-diff
-                        """
-                    )
-                    # pylint: enable=C0301
-                    sys.stderr.write(msg)
-                    return 1
-
                 try:
                     actually_mutated = (
                         REPLACE_FUNCTION[configs["diff"]](
@@ -535,7 +543,7 @@ def _main(  # pylint: disable=R0912,R0914,R0911
         if configs["diff"]:
             if mutated:
                 sys.stdout.write(
-                    "To apply these changes use `--nbqa-mutate` instead of `--nbqa-diff`\n"
+                    "To apply these changes, remove the `--nbqa-diff` flag\n"
                 )
             return output_code
 
@@ -595,7 +603,6 @@ def main(argv: Optional[Sequence[str]] = None) -> int:
     _check_command_is_installed(cli_args.command)
     project_root: Path = find_project_root(tuple(cli_args.root_dirs))
     configs: Configs = _get_configs(cli_args, project_root)
-    validate(configs)
 
     return _main(cli_args, configs)
 
