@@ -5,10 +5,10 @@ Markdown cells, output, and metadata are ignored.
 """
 
 import ast
-import json
 import secrets
 from collections import defaultdict
 from typing import (
+    Any,
     DefaultDict,
     List,
     Mapping,
@@ -21,12 +21,7 @@ from typing import (
 import tokenize_rt
 from IPython.core.inputtransformer2 import TransformerManager
 
-from nbqa.handle_magics import (
-    CellMagicFinder,
-    MagicHandler,
-    SystemAssignsFinder,
-    Visitor,
-)
+from nbqa.handle_magics import CellMagicFinder, MagicHandler, Visitor
 from nbqa.notebook_info import NotebookInfo
 from nbqa.path_utils import remove_prefix
 
@@ -35,6 +30,14 @@ MAGIC = frozenset(("time", "timeit", "capture", "pypy", "python", "python3"))
 NEWLINE = "\n"
 NEWLINES = defaultdict(lambda: NEWLINE * 3)
 NEWLINES["isort"] = NEWLINE * 2
+TRANSFORMED_MAGICS = frozenset(
+    (
+        "get_ipython().run_cell_magic",
+        "get_ipython().system",
+        "get_ipython().getoutput",
+        "get_ipython().run_line_magic",
+    )
+)
 
 
 class Index(NamedTuple):
@@ -72,9 +75,7 @@ def _process_source(
         handler = MagicHandler(source, command, magic_type=None)
         magic_substitutions.append(handler)
         return handler.replacement
-    system_assigns_finder = SystemAssignsFinder()
-    system_assigns_finder.visit(tree)
-    visitor = Visitor(system_assigns_finder.system_assigns)
+    visitor = Visitor()
     visitor.visit(tree)
     new_src = []
     for i, line in enumerate(body.splitlines(), start=1):
@@ -256,22 +257,24 @@ def _should_ignore_code_cell(
     bool
         True if the cell should ignored else False
     """
-    if not "".join(source):
+    joined_source = "".join(source)
+    if (
+        not joined_source
+        or set(tags).intersection(skip_celltags)
+        or any(magic in joined_source for magic in TRANSFORMED_MAGICS)
+    ):
         return True
-    if set(tags).intersection(skip_celltags):
-        return True
-
     try:
-        ast.parse("".join(source))
+        ast.parse(joined_source)
     except SyntaxError:
         # Deal with this below
         pass
     else:
-        # No need to ignore
+        # Syntax is fine, no need to ignore
         return False
 
     cell_magic_finder = CellMagicFinder()
-    body = TransformerManager().transform_cell("".join(source))
+    body = TransformerManager().transform_cell(joined_source)
     try:
         tree = ast.parse(body)
     except SyntaxError:
@@ -317,7 +320,7 @@ def _has_trailing_semicolon(src: str) -> Tuple[str, bool]:
 
 
 def main(  # pylint: disable=R0914
-    notebook: str,
+    notebook_json: MutableMapping[str, Any],
     file_descriptor: int,
     process_cells: Sequence[str],
     command: str,
@@ -330,7 +333,7 @@ def main(  # pylint: disable=R0914
 
     Parameters
     ----------
-    notebook
+    notebook_json
         Jupyter Notebook third-party tool is being run against.
     process_cells
         Extra cells which nbqa should process.
@@ -342,10 +345,7 @@ def main(  # pylint: disable=R0914
     NotebookInfo
 
     """
-    with open(str(notebook), encoding="utf-8") as handle:
-        content = handle.read()
-
-    cells = json.loads(content)["cells"]
+    cells = notebook_json["cells"]
 
     result = []
     cell_mapping = {0: "cell_0:0"}
